.. _radiation:

************************************************************************
Electromagnetic Radiation Functions (`plasmapy.formulary.radiation`)
************************************************************************

.. currentmodule:: plasmapy.formulary.radiation

.. automodapi:: plasmapy.formulary.radiation

See Also
========
`astropy.modeling.physical_models.BlackBody`

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/thermal_bremsstrahlung
